Appias: machine learning workflow toolkit
==========================

[![image](https://img.shields.io/pypi/v/appias.svg)](https://pypi.org/project/appias/)
[![image](https://img.shields.io/pypi/l/appias.svg)](https://pypi.org/project/appias/)
[![image](https://img.shields.io/pypi/pyversions/appias.svg)](https://pypi.org/project/appias/)
[![image](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/aglove2189)

A small library for gluing together a few of the standard steps when exploring a dataset and building a model. Built on pandas, sklearn, and matplotlib.

<img src="https://raw.githubusercontent.com/aglove2189/appias/master/logo/logo.svg?sanitize=true" height="120">

Features
---------------

-   Explore
-   Plot
-   Remove Outliers
-   Replace and Impute NAs
-   Reduce Pandas Memory Usage
-   Transform
-   Fit, Predict, and Score
-   Cross Validate
-   Logging

[Example Notebook](examples/demo.ipynb)
---------------

Installation
---------------

``` sh
pip install appias
```

Documentation
---------------
Coming Soon!
